@@ -25,15 +25,21 @@ home_dir = os.path.expanduser('~/.nanote/')
 make_dir_if_not_exists(home_dir)
 config_file_path = os.path.join(home_dir, 'settings')
 
-defaults = {
-            'path': os.path.join(home_dir, 'notes'),
-            'default_note': '',
-            'tab_width': '4',
-}
+defaults = [
+            ('path', os.path.join(home_dir, 'notes')),
+            ('default_note', ''),
+            ('tab_width', '4'),
+            ('link_re', '\[[a-zA-Z0-9\_\-\.\:\/]+\]'),
+            ('bold_re', '\*[^ ^\[^\]^*^_][^\[^\]^*^_]*?\*'),
+            ('underline_re', '\_[^ ^\[^\]^*^_][^\[^\]^*^_]*?\_'),
+            ('bullet_re', '^ *\* .*'),
+            ('bullet_symbols', '*o>-+'),
+            ('comment_re', '\#.*'),
+            ]
 
 config = ConfigParser.SafeConfigParser()
 if not config.has_section('nanote'): config.add_section('nanote')
-for key, value in defaults.items():
+for key, value in defaults:
     config.set('nanote', key, value)
 config.read(config_file_path)
 if not os.path.exists(config_file_path): 
@@ -43,7 +49,7 @@ if not os.path.exists(config_file_path):
 # get note search paths
 # TODO: parse sys.argv arguments
 args = {}
-for arg in ('path', 'default_note', 'tab_width'):
+for arg, _ in defaults:
     args[arg] = config.get('nanote', arg)
         
 if len(sys.argv) > 1: args['default_note'] = sys.argv[1]
